@@ -17,15 +17,19 @@ def on_worker_process_init(**kwargs):
         ports = settings.DEPLOY_ONNX_AVAILABLE_PORT.split(",")
     else:
         ports = []
-    is_success = worker_online(
-        settings.CELERY_WORKER_NAME,
-        settings.CELERY_WORKER_LISTEN_QUEUE,
-        settings.CELERY_WORKER_CONCURRENCY,
-        settings.DEPLOY_ONNX_IP_ADDRESS,
-        ports,
-    )
-    if not is_success:
+    try:
+        is_success = worker_online(
+            settings.CELERY_WORKER_NAME,
+            settings.CELERY_WORKER_LISTEN_QUEUE,
+            settings.CELERY_WORKER_CONCURRENCY,
+            settings.DEPLOY_ONNX_IP_ADDRESS,
+            ports,
+        )
+    except Exception:
         exit()
+    else:
+        if not is_success:
+            exit()
 
 
 @worker_shutdown.connect
