@@ -36,7 +36,8 @@ def pytorch_object_detection_train(
 
 @celery_app.task
 def deploy_onnx_infer_by_train_task(
-    deploy_id: str, inner_token: str, train_result_url: str | None = None, is_gpu: bool = False
+    deploy_id: str, inner_token: str, train_result_url: str | None = None, is_gpu: bool = False,
+    service_type: str = "OBJECT_DETECTION"
 ):
-    deploy_onnx_infer = DeployOnnxInfer(deploy_id, inner_token, train_result_url, is_gpu)
+    deploy_onnx_infer = DeployOnnxInfer(deploy_id, inner_token, train_result_url, service_type, is_gpu)
     deploy_onnx_infer()
