@@ -75,7 +75,8 @@ class DeployOnnxInfer:
 
     def docker_run(self, port: int) -> str:
         client = docker.from_env()
-        client.images.pull(self.docker_image_name)
+        # 由于dockerhub被墙暂时取消在此逻辑中拉取镜像
+        # client.images.pull(self.docker_image_name)
         factor = random.randint(1000, 9999)  # 添加随机数避免容器名称重复
         container_name = f"{self.docker_image_name.split(':')[0].split('/')[-1]}-{factor}-{port}"
         f"{settings.DEPLOY_TARGET_CONTAINER_WORKDIR}/{settings.DEPLOY_ONNX_WEIGHT_DIR}"
