@@ -16,9 +16,12 @@ class Settings(BaseSettings):
     DEPLOY_ONNX_WEIGHT_DIR: str = "onnx_weight"
     DEPLOY_ONNX_DOCKER_IMAGE_CPU: str = "ai-butler-onnx-infer-service-cpu"
     DEPLOY_ONNX_DOCKER_IMAGE_GPU: str = "ai-butler-onnx-infer-service-gpu"
+    DEPLOY_TARGET_CONTAINER_WORKDIR: str = "/srv/app"
 
     DEPLOY_ONNX_IP_ADDRESS: str = ""
     DEPLOY_ONNX_AVAILABLE_PORT: str = ""  # 逗号分割多个端口
+    # 宿主机的项目目录, 在docker中启动另一个docker, 挂载目录需要挂载宿主机的真实目录地址
+    DEPLOY_HOST_DIR: str = ""
 
     class Config:
         env_file = ".envs"
