@@ -74,7 +74,7 @@ class TrainBase:
                         # 可选地在这里调用flush来确保数据及时写入磁盘
                         f.flush()
                 # 解压文件
-                unzip_file(target_path, target_path[:-4])
+                unzip_file(target_path, self.pretrain_local_path)
             os.remove(target_path)  # 删除压缩包
             logger.info("---------------------------------预训练文件下载完成---------------------------------")
 
@@ -87,7 +87,7 @@ class TrainBase:
         pass
 
     def train(self):
-        pass
+        raise NotImplementedError
 
     def after_train(self):
         pass
@@ -113,6 +113,7 @@ class TrainBase:
         logger.info("---------------------------------训练日志上传完成---------------------------------")
 
     def __call__(self):
+        is_exception = False
         try:
             update_train_task_status(self.train_task_id, TrainStatusEnum.TRAINING)
             self.download()
@@ -123,8 +124,10 @@ class TrainBase:
         except Exception:
             logger.error(f"训练任务失败: {traceback.format_exc()}")
             update_train_task_status(self.train_task_id, TrainStatusEnum.FAILURE)
+            is_exception = True
         else:
             update_train_task_status(self.train_task_id, TrainStatusEnum.FINISH)
         finally:
             self.upload_log()
-            shutil.rmtree(self.root_path, ignore_errors=True)
+            if not is_exception:  # 没有异常时删除目录, 异常时保留数据集用于排查
+                shutil.rmtree(self.root_path, ignore_errors=True)
